@@ -26,6 +26,7 @@ from weblate_language_data.country_codes import COUNTRIES
 from weblate_language_data.language_codes import LANGUAGES
 
 from ..chardet import detect_charset
+from ..data import LANGUAGES_BLACKLIST
 from .result import DiscoveryResult
 
 TOKEN_SPLIT = re.compile(r"([_.-])")
@@ -57,10 +58,11 @@ TEMPLATE_REPLACEMENTS = (
     ("-*", ""),
     (".*", ""),
     ("*", ""),
+    ("*", "templates"),
 )
 
 
-class BaseDiscovery(object):
+class BaseDiscovery:
     """Abstract base class for discovery."""
 
     file_format = ""
@@ -82,17 +84,22 @@ class BaseDiscovery(object):
     def is_language_code(cls, code):
         """Analysis whether passed parameter looks like language code."""
         code = code.lower().replace("-", "_")
-        if code in LANGUAGES:
+        if code in LANGUAGES and code not in LANGUAGES_BLACKLIST:
             return True
 
         if "_" in code:
             lang, country = code.split("_", 1)
-            if lang in LANGUAGES and cls.is_country_code(country):
+            if (
+                lang in LANGUAGES
+                and lang not in LANGUAGES_BLACKLIST
+                and cls.is_country_code(country)
+            ):
                 return True
 
         return False
 
-    def detect_format(self, filemask):
+    @staticmethod
+    def detect_format(filemask):
         filemask = filemask.lower()
         for end, result in EXTENSION_MAP:
             if filemask.endswith(end):
@@ -156,7 +163,8 @@ class BaseDiscovery(object):
         """Check whether finder has a storage."""
         return self.finder.has_file(name)
 
-    def get_language_aliases(self, language):
+    @staticmethod
+    def get_language_aliases(language):
         """Language code aliases."""
         return [language]
 
@@ -183,7 +191,8 @@ class BaseDiscovery(object):
         if "file_format" not in result:
             result["file_format"] = self.file_format
 
-    def adjust_format(self, result):
+    @staticmethod
+    def adjust_format(result):
         return
 
     def discover(self):
@@ -236,12 +245,16 @@ class BaseDiscovery(object):
 
 
 class MonoTemplateDiscovery(BaseDiscovery):
+    """Base class for monolingual template based files."""
+
     def fill_in_new_base(self, result):
         if "new_base" not in result and "template" in result:
             result["new_base"] = result["template"]
 
 
 class EncodingDiscovery(BaseDiscovery):
+    """Base class for formats needing encoding detection."""
+
     encoding_map = {}
 
     def adjust_format(self, result):
