@@ -49,7 +49,8 @@ TEST_DATA = os.path.join(os.path.dirname(__file__), "test_data")
 class DiscoveryTestCase(TestCase):
     maxDiff = None
 
-    def get_finder(self, paths, dirs=None):
+    @staticmethod
+    def get_finder(paths, dirs=None):
         if dirs is None:
             dirs = []
         return Finder(
@@ -60,7 +61,8 @@ class DiscoveryTestCase(TestCase):
             ),
         )
 
-    def get_real_finder(self):
+    @staticmethod
+    def get_real_finder():
         return Finder(TEST_DATA)
 
     def assert_discovery(self, first, second):
@@ -516,6 +518,34 @@ class QtTest(DiscoveryTestCase):
             ],
         )
 
+    def test_po_mono_template(self):
+        discovery = GettextDiscovery(
+            self.get_finder(
+                [
+                    "PoFiles/templates",
+                    "PoFiles/templates/MdeMeta.pot",
+                    "PoFiles/en/MdeMeta.po",
+                    "PoFiles/de/MdeMeta.po",
+                ]
+            )
+        )
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "file_format": "po",
+                    "filemask": "PoFiles/*/MdeMeta.po",
+                    "new_base": "PoFiles/templates/MdeMeta.pot",
+                },
+                {
+                    "file_format": "po-mono",
+                    "filemask": "PoFiles/*/MdeMeta.po",
+                    "new_base": "PoFiles/templates/MdeMeta.pot",
+                    "template": "PoFiles/en/MdeMeta.po",
+                },
+            ],
+        )
+
 
 class AndroidTest(DiscoveryTestCase):
     def test_basic(self):
